summaryrefslogtreecommitdiff
path: root/libc/stdio
diff options
context:
space:
mode:
authorEric Andersen <andersen@codepoet.org>2002-02-18 10:12:45 +0000
committerEric Andersen <andersen@codepoet.org>2002-02-18 10:12:45 +0000
commita7941d4f375573864334e1002aed2880ae47fa6a (patch)
treed2222e9f68dc627ea4418148f79d67406b967de4 /libc/stdio
parent623b520a8115c6a2bd1af9c13c9e1ace924cf7e6 (diff)
Rename __stdio_close_all to __stdio_flush_buffers. Eliminate an
unnecessary variable
Diffstat (limited to 'libc/stdio')
-rw-r--r--libc/stdio/stdio.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libc/stdio/stdio.c b/libc/stdio/stdio.c
index d35dd7a66..45cd0b8ec 100644
--- a/libc/stdio/stdio.c
+++ b/libc/stdio/stdio.c
@@ -193,10 +193,10 @@ FILE *_free_file_list = 0;
char _free_buffer_index = FIXED_BUFFERS;
/*
* __stdio_close_all is automatically when exiting if stdio is used.
* See misc/internals/__uClibc_main.c and and stdlib/atexit.c.
*/
-void __stdio_close_all(void)
+void __stdio_flush_buffers(void)
{
fflush(NULL); /* Files will be closed on _exit call. */
}
@@ -193,10 +193,10 @@ FILE *_free_file_list = 0;
char _free_buffer_index = FIXED_BUFFERS;
/*
- * __stdio_close_all is automatically when exiting if stdio is used.
+ * __stdio_flush_buffers is automatically when exiting if stdio is used.
* See misc/internals/__uClibc_main.c and and stdlib/atexit.c.
*/